ClassInfo<T> class

Used to lookup type information for a given class. One will be generated for each class annotated with Transportable or Storable.

Constructors

ClassInfo({required String tableName, required T fromJson(Map<String, dynamic> json), required Map<String, dynamic> toJson(T)})
const

Properties

fromJson → T Function(Map<String, dynamic> json)
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tableName String
final
toJson Map<String, dynamic> Function(T)
final
type Type
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited