SelectorBuilder class
The main interface through which Selectors are built. This is modeled after mongo_dart_query, however unlike mongo_dart_query this is immutable. Typically used via the global where variable. e.g. where.eq('name', 'Bob').gt('age', 18).limit(10)
Constructors
-
SelectorBuilder([List<
Selector> selectors = const []]) -
const
Properties
Methods
-
eq(
String field, Object value) → SelectorBuilder - Add an equality selector to the query.
-
gte(
String field, Object value) → SelectorBuilder - Add a greater than or equal to selector to the query.
-
id(
ObjectId id) → SelectorBuilder - Add an id selector to the query.
-
limit(
int limit) → SelectorBuilder - Add a limit selector to the query.
-
lte(
String field, Object value) → SelectorBuilder - Add a less than or equal to selector to the query.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sortBy(
String field, {bool descending = false}) → SelectorBuilder - Add a sort selector to the query.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited